==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSRecordListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSRecordListBuilder extends io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluentImpl<io.fabric8.openshift.api.model.operator.v1.DNSRecordListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.DNSRecordList,io.fabric8.openshift.api.model.operator.v1.DNSRecordListBuilder>{
  public DNSRecordListBuilder() {
    this(false);
  }
  public DNSRecordListBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSRecordList(), validationEnabled);
  }
  public DNSRecordListBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSRecordListBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSRecordList(), validationEnabled);
  }
  public DNSRecordListBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSRecordList instance) {
    this(fluent, instance, false);
  }
  public DNSRecordListBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSRecordList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSRecordListBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordList instance) {
    this(instance,false);
  }
  public DNSRecordListBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordList build() {
    DNSRecordList buildable = new DNSRecordList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSRecordListBuilder that = (DNSRecordListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.6.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSRecordListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSRecordListBuilder extends DNSRecordListFluentImpl<DNSRecordListBuilder> implements VisitableBuilder<DNSRecordList,DNSRecordListBuilder>{
  public DNSRecordListBuilder() {
    this(false);
  }
  public DNSRecordListBuilder(Boolean validationEnabled) {
    this(new DNSRecordList(), validationEnabled);
  }
  public DNSRecordListBuilder(DNSRecordListFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSRecordListBuilder(DNSRecordListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSRecordList(), validationEnabled);
  }
  public DNSRecordListBuilder(DNSRecordListFluent<?> fluent,DNSRecordList instance) {
    this(fluent, instance, false);
  }
  public DNSRecordListBuilder(DNSRecordListFluent<?> fluent,DNSRecordList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSRecordListBuilder(DNSRecordList instance) {
    this(instance,false);
  }
  public DNSRecordListBuilder(DNSRecordList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DNSRecordListFluent<?> fluent;
  Boolean validationEnabled;
  public DNSRecordList build() {
    DNSRecordList buildable = new DNSRecordList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
